CR-Nimble
=====================================
Iterative algorithms for numerical linear algebra with JAX


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   start
   source/index
   zzzreference
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
